@@ -3,20 +3,7 @@ import logging
 
 import attr
 
-from hatasmota.const import (
-    CONF_MAC,
-    CONF_LIGHT_SUBTYPE,
-    CONF_OPTIONS,
-    CONF_RELAY,
-    OPTION_PWM_MULTI_CHANNELS,
-    OPTION_REDUCED_CT_RANGE,
-    CONF_LINK_RGB_CT,
-    LST_COLDWARM,
-    LST_NONE,
-    LST_RGB,
-    LST_RGBCW,
-    LST_RGBW,
-    LST_SINGLE,
+from .const import (
     COMMAND_CHANNEL,
     COMMAND_COLOR,
     COMMAND_CT,
@@ -26,27 +13,40 @@ from hatasmota.const import (
     COMMAND_SCHEME,
     COMMAND_SPEED,
     COMMAND_WHITE,
+    CONF_LIGHT_SUBTYPE,
+    CONF_LINK_RGB_CT,
+    CONF_MAC,
+    CONF_OPTIONS,
+    CONF_RELAY,
+    LST_COLDWARM,
+    LST_NONE,
+    LST_RGB,
+    LST_RGBCW,
+    LST_RGBW,
+    LST_SINGLE,
+    OPTION_PWM_MULTI_CHANNELS,
+    OPTION_REDUCED_CT_RANGE,
     RL_LIGHT,
 )
-from hatasmota.entity import (
+from .entity import (
     TasmotaAvailability,
     TasmotaAvailabilityConfig,
     TasmotaEntity,
     TasmotaEntityConfig,
 )
-from hatasmota.mqtt import send_commands
-from hatasmota.utils import (
+from .mqtt import send_commands
+from .utils import (
     config_get_friendlyname,
+    config_get_state_offline,
+    config_get_state_online,
+    config_get_state_power_off,
+    config_get_state_power_on,
     get_state_power,
     get_topic_command,
     get_topic_command_state,
     get_topic_tele_state,
     get_topic_tele_will,
     get_value_by_path,
-    config_get_state_offline,
-    config_get_state_online,
-    config_get_state_power_off,
-    config_get_state_power_on,
 )
 
 LIGHT_TYPE_NONE = 0
@@ -129,6 +129,8 @@ class TasmotaLightConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
             friendly_name=config_get_friendlyname(config, platform, idx),
             mac=config[CONF_MAC],
             platform=platform,
+            poll_payload="",
+            poll_topic=get_topic_command_state(config),
             availability_topic=get_topic_tele_will(config),
             availability_offline=config_get_state_offline(config),
             availability_online=config_get_state_online(config),
@@ -139,7 +141,6 @@ class TasmotaLightConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
             light_type=light_type,
             max_mireds=max_mireds,
             min_mireds=min_mireds,
-            poll_topic=get_topic_command_state(config),
             state_power_off=config_get_state_power_off(config),
             state_power_on=config_get_state_power_on(config),
             state_topic=get_topic_tele_state(config),
@@ -153,19 +154,9 @@ class TasmotaLight(TasmotaAvailability, TasmotaEntity):
         """Initialize."""
         self._brightness = None
         self._state = None
-        self._on_state_callback = None
         self._sub_state = None
         super().__init__(**kwds)
 
-    def poll_status(self):
-        """Poll for status."""
-        payload = ""
-        self._mqtt_client.publish_debounced(self._cfg.poll_topic, payload)
-
-    def set_on_state_callback(self, on_state_callback):
-        """Set callback for state change."""
-        self._on_state_callback = on_state_callback
-
     async def subscribe_topics(self):
         """Subscribe to topics."""
 
